summaryrefslogtreecommitdiff
path: root/epan
diff options
context:
space:
mode:
Diffstat (limited to 'epan')
-rw-r--r--epan/emem.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/emem.c b/epan/emem.c
index 27e11c78b3..1f710ac9a6 100644
--- a/epan/emem.c
+++ b/epan/emem.c
@@ -266,9 +266,9 @@ ep_check_canary_integrity(const char* fmt, ...)
while (canary_next != NULL) {
canary_next = emem_canary_next(ep_packet_mem.canary, canary_next, NULL);
- /* XXX, check if canary_last is inside allocated memory? */
+ /* XXX, check if canary_next is inside allocated memory? */
- if (npc->canary_last == (void *) -1)
+ if (canary_next == (void *) -1)
g_error("Per-packet memory corrupted\nbetween: %s\nand: %s", there, here);
}
}